@@ -54,6 +54,7 @@ void Nepomuk2::TagWidgetPrivate::init( TagWidget* parent )
     m_flags = TagWidget::StandardMode;
     m_blockSelectionChangedSignal = false;
     m_showAllLinkLabel = 0;
+    m_editTagsDialog = 0;
 
     QGridLayout* mainLayout = new QGridLayout( q );
     mainLayout->setMargin(0);
@@ -164,7 +165,7 @@ Nepomuk2::TagCheckBox* Nepomuk2::TagWidgetPrivate::getTagCheckBox( const Tag& ta
 {
     QMap<Tag, TagCheckBox*>::iterator it = m_checkBoxHash.find(tag);
     if( it == m_checkBoxHash.end() ) {
-        kDebug() << "Creating checkbox for" << tag.genericLabel();
+        //kDebug() << "Creating checkbox for" << tag.genericLabel();
         TagCheckBox* checkBox = new TagCheckBox( tag, this, q );
         q->connect( checkBox, SIGNAL(tagClicked(Nepomuk2::Tag)), SIGNAL(tagClicked(Nepomuk2::Tag)) );
         q->connect( checkBox, SIGNAL(tagStateChanged(Nepomuk2::Tag,int)), SLOT(slotTagStateChanged(Nepomuk2::Tag,int)) );
@@ -266,6 +267,7 @@ Nepomuk2::TagWidget::TagWidget( const Resource& resource, QWidget* parent )
     : QWidget( parent ),
       d( new TagWidgetPrivate() )
 {
+    setForegroundRole(parent->foregroundRole());
     d->init( this );
     setTaggedResource( resource );
 }
@@ -275,6 +277,7 @@ Nepomuk2::TagWidget::TagWidget( QWidget* parent )
     : QWidget( parent ),
       d( new TagWidgetPrivate() )
 {
+    setForegroundRole(parent->foregroundRole());
     d->init( this );
 }
 
@@ -396,11 +399,21 @@ void Nepomuk2::TagWidget::slotTagUpdateDone()
 
 void Nepomuk2::TagWidget::slotShowAll()
 {
-    KEditTagsDialog dlg( selectedTags(), this );
-    if( dlg.exec() ) {
-        setSelectedTags( dlg.tags() );
+    d->m_editTagsDialog = new KEditTagsDialog( selectedTags(), this );
+    d->m_editTagsDialog->setWindowModality( Qt::ApplicationModal );
+    connect( d->m_editTagsDialog, SIGNAL(finished(int)), this, SLOT(slotKEditTagDialogFinished(int)) );
+    d->m_editTagsDialog->open();
+}
+
+void Nepomuk2::TagWidget::slotKEditTagDialogFinished(int result)
+{
+    if( result == QDialog::Accepted ) {
+        setSelectedTags( d->m_editTagsDialog->tags() );
         emit selectionChanged( selectedTags() );
     }
+
+    d->m_editTagsDialog->deleteLater();
+    d->m_editTagsDialog = 0;
 }
 
 
